function A=randidiag(I,N,d,varargin)
% -- fc_amat.random.randidiag(Imax,N,d)
%      Returns a N-by-d-by-d amat object whose matrices are diagonal and 
%      non zeros elements are drawn from the discrete uniform distribution 
%      on 1:Imax.
%
% -- fc_amat.random.randidiag([Imin,Imax],N,d)
%      Returns a N-by-d-by-d amat object whose matrices are diagonal and 
%      non zeros elements are drawn from the discrete uniform distribution 
%      on Imin:Imax.
%
% -- fc_amat.random.randidiag(...,key,value)
%      Some optional key/value pairs arguments are available with keys:
%        - 'complex', if value is true the amat object is complex and the
%                     imaginary parts of the diagonal matrices elements are 
%                     drawn from the same distribution.
%                     (default false i.e real amat object)
%        - 'class',   value could be 'single' or 'double' (default).
%        - 'nc',      number of columns of matrices (default: d)
%        - 'k',       offset of k diagonals above or below the main diagonal; 
%                     above for positive k and below for negative k.
%
  p = inputParser;
  p.addParamValue('complex',false,@islogical); 
  p.addParamValue('class','double',@(x) ismember(lower(x),{'single','double'}));
  p.addParamValue('nc',d,@isscalar); % number of columns
  p.addParamValue('k',0,@isscalar); % diag number
  p.parse(varargin{:});
  R=p.Results;
  if R.complex
    A=complex(amat(N,d,d,R.class));
    gen=@() complex(randi(I,N,1,R.class),randi(I,N,1,R.class));
  else
    A=amat(N,d,d,R.class);
    gen=@() randi(I,N,1,R.class);
  end
  for i=1:min(d,R.nc)
    j=i+R.k;
    if ( j>=1 && j<=R.nc ), A(i,j)=gen(); end
  end
end
